==========
snowmobile
==========

A simple set of modules for streamlined interaction with the Snowflake Database.

-----

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   License <license>
   Authors <authors>
   Changelog <changelog>
   autoapi/snowmobile/index

Indices and tables
==================

* :ref:`modindex`
* :ref:`search`
